@@ -1,4 +1,4 @@
-# Marpa::R3 is Copyright (C) 2017, Jeffrey Kegler.
+# Marpa::R3 is Copyright (C) 2018, Jeffrey Kegler.
 #
 # This module is free software; you can redistribute it and/or modify it
 # under the same terms as Perl 5.10.1. For more details, see the full text
@@ -16,7 +16,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '4.001_051';
+$VERSION        = '4.001_052';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -1850,7 +1850,10 @@ sub Marpa::R3::Internal::MetaAST::Parse::prioritized_symbol {
         name_source => 'lexical',
     };
     $parse->xsy_assign( $base_symbol, $symbol_data );
-    $symbol_data = { xsy => $base_symbol };
+    $symbol_data = {
+        xsy => $base_symbol,
+        precedence => $priority,
+    };
     $parse->symbol_names_set( $symbol_name, $Marpa::R3::Internal::SUBGRAMMAR,
         $symbol_data );
     return $symbol_name;
