@@ -1,4 +1,4 @@
-# Marpa::R3 is Copyright (C) 2017, Jeffrey Kegler.
+# Marpa::R3 is Copyright (C) 2018, Jeffrey Kegler.
 #
 # This module is free software; you can redistribute it and/or modify it
 # under the same terms as Perl 5.10.1. For more details, see the full text
@@ -16,7 +16,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '4.001_051';
+$VERSION        = '4.001_052';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -818,7 +818,7 @@ sub Marpa::R3::Grammar::nrls_show {
         <<'END_OF_LUA', '' );
     local grammar = ...
     local g1g = grammar.g1
-    local nrl_count = g1g:_irl_count()
+    local nrl_count = g1g:_nrl_count()
     local pieces = {}
     for nrl_id = 0, nrl_count - 1 do
         pieces[#pieces+1] = g1g:brief_nrl(nrl_id)
